@@ -14,16 +14,13 @@
 # under the License.
 
 from django.conf import settings
-from django.core.urlresolvers import reverse
-from django.forms import ValidationError  # noqa
-from django.template.defaultfilters import filesizeformat  # noqa
+from django.forms import ValidationError
+from django.urls import reverse
 from django.utils.translation import ugettext_lazy as _
 from horizon import exceptions
 from horizon import forms
 from horizon import messages
-from horizon.utils.memoized import memoized  # noqa
-from openstack_dashboard.usage import quotas
-import six
+from horizon.utils.memoized import memoized
 
 from manila_ui.api import manila
 from manila_ui.dashboards import utils
@@ -60,7 +57,10 @@ class CreateForm(forms.SelfHandlingForm):
         share_networks = manila.share_network_list(request)
         share_types = manila.share_type_list(request)
         self.fields['share_type'].choices = (
-            [("", "")] + [(st.name, st.name) for st in share_types])
+            [("", "")] +
+            [(utils.transform_dashed_name(st.name), st.name)
+             for st in share_types]
+        )
 
         availability_zones = manila.availability_zone_list(request)
         self.fields['availability_zone'].choices = (
@@ -80,19 +80,22 @@ class CreateForm(forms.SelfHandlingForm):
             dhss = extra_specs.get('driver_handles_share_servers')
             # NOTE(vponomaryov): Set and tie share-network field only for
             # share types with enabled handling of share servers.
-            if (isinstance(dhss, six.string_types) and
-                    dhss.lower() in ['true', '1']):
+            if (isinstance(dhss, str) and dhss.lower() in ['true', '1']):
                 sn_choices = (
                     [('', '')] +
                     [(sn.id, sn.name or sn.id) for sn in share_networks])
-                sn_field_name = self.sn_field_name_prefix + st.name
+                sn_field_name = (
+                    self.sn_field_name_prefix +
+                    utils.transform_dashed_name(st.name)
+                )
                 sn_field = forms.ChoiceField(
                     label=_("Share Network"), required=True,
                     choices=sn_choices,
                     widget=forms.Select(attrs={
                         'class': 'switched',
                         'data-switch-on': 'sharetype',
-                        'data-sharetype-%s' % st.name: _("Share Network"),
+                        'data-sharetype-%s' % utils.transform_dashed_name(
+                            st.name): _("Share Network"),
                     }))
                 self.fields[sn_field_name] = sn_field
 
@@ -164,7 +167,7 @@ class CreateForm(forms.SelfHandlingForm):
                     del self.fields['snapshot']
             except Exception:
                 exceptions.handle(request, _("Unable to retrieve "
-                                  "share snapshots."))
+                                             "share snapshots."))
 
             if source_type_choices:
                 choices = ([('no_source_type',
@@ -176,22 +179,21 @@ class CreateForm(forms.SelfHandlingForm):
 
     def clean(self):
         cleaned_data = super(CreateForm, self).clean()
-        errors = [k for k in self.errors.viewkeys()]
+        form_errors = list(self.errors)
 
-        # NOTE(vponomaryov): skip errors for share-network fields that are not
-        # related to chosen share type.
-        for k in errors:
-            st_name = k.split(self.sn_field_name_prefix)[-1]
-            chosen_st = cleaned_data.get('share_type')
-            if (k.startswith(self.sn_field_name_prefix) and
-                    st_name != chosen_st):
-                cleaned_data[k] = 'Not set'
-                self.errors.pop(k, None)
+        chosen_share_type = cleaned_data.get('share_type')
+        if chosen_share_type:
+            # NOTE(vponomaryov): skip errors for share-network fields that are
+            # not related to chosen share type.
+            for error in form_errors:
+                st_name = error.split(self.sn_field_name_prefix)[-1]
+                if (error.startswith(self.sn_field_name_prefix) and
+                        st_name != chosen_share_type):
+                    cleaned_data[error] = 'Not set'
+                    self.errors.pop(error, None)
 
-        share_type = cleaned_data.get('share_type')
-        if share_type:
             cleaned_data['share_network'] = cleaned_data.get(
-                self.sn_field_name_prefix + share_type)
+                self.sn_field_name_prefix + cleaned_data.get('share_type'))
 
         return cleaned_data
 
@@ -232,7 +234,7 @@ class CreateForm(forms.SelfHandlingForm):
                 proto=data['share_proto'],
                 share_network=share_network,
                 snapshot_id=snapshot_id,
-                share_type=data['share_type'],
+                share_type=utils.transform_dashed_name(data['share_type']),
                 is_public=is_public,
                 metadata=metadata,
                 availability_zone=data['availability_zone'],
@@ -299,7 +301,7 @@ class UpdateMetadataForm(forms.SelfHandlingForm):
     def __init__(self, *args, **kwargs):
         super(UpdateMetadataForm, self).__init__(*args, **kwargs)
         meta_str = ""
-        for k, v in self.initial["metadata"].iteritems():
+        for k, v in self.initial["metadata"].items():
             meta_str += "%s=%s\r\n" % (k, v)
         self.initial["metadata"] = meta_str
 
@@ -381,7 +383,7 @@ class ExtendForm(forms.SelfHandlingForm):
             self._errors["new_size"] = self.error_class([message])
             return cleaned_data
 
-        usages = quotas.tenant_limit_usages(self.request)
+        usages = manila.tenant_absolute_limits(self.request)
         availableGB = (usages['maxTotalShareGigabytes'] -
                        usages['totalShareGigabytesUsed'])
         if availableGB < (new_size - orig_size):
